__title__ = 'enlightenme'
__description__ = 'LI for curating and reading news/updates.'
__url__ = 'https://github.com/singhgarima/enlightenme'
__version__ = '0.0.5'
__author__ = 'Garima Singh'
__author_email__ = 'igarimasingh+enlightenme@gmail.com'
__license__ = 'MIT License'
__copyright__ = 'Copyright 2018 Garima Singh'
